package com.chelvc.cloud.maintain.controller;

import java.io.IOException;
import java.io.InputStream;

import com.chelvc.framework.base.annotation.UnifiedResponseBody;
import com.chelvc.framework.base.util.FileUtils;
import com.chelvc.framework.base.util.StringUtils;
import com.chelvc.framework.upload.UploadHandler;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * 文件接口
 *
 * @author Woody
 * @date 2023/5/4
 */
@Validated
@RestController
@UnifiedResponseBody
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class FileController {
    private final UploadHandler uploadHandler;

    /**
     * 上传文件
     *
     * @param file 文件对象
     * @return 文件地址
     * @throws IOException I/O异常
     */
    @PostMapping("/file")
    public String upload(@RequestParam("file") MultipartFile file) throws IOException {
        String suffix = StringUtils.ifEmpty(file.getOriginalFilename(), FileUtils::getSuffix);
        try (InputStream stream = file.getInputStream()) {
            return this.uploadHandler.upload(stream, suffix);
        }
    }
}
